OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "ไฟล์อัปโหลดแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า MAX_FILE_SIZE ที่ระบุไว้ในรูปแบบของ HTML",
    "The file was only partially uploaded" : "ไฟล์ถูกอัปโหลดเพียงบางส่วน",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัปโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวขาดหาย",
    "Could not write file to disk" : "ไม่สามารถเขียนไฟล์ลงดิสก์",
    "A PHP extension stopped the file upload" : "ส่วนขยาย PHP ได้หยุดการอัปโหลดไฟล์",
    "Text" : "ข้อความ",
    "Translate" : "แปลภาษา",
    "guest" : "ผู้เยี่ยมชม",
    "Offline" : "ออฟไลน์",
    "Saving …" : "กำลังบันทึก …",
    "Saved" : "บันทึกแล้ว",
    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
    "Save changes" : "บันทึกการเปลี่ยนแปลง",
    "Cancel" : "ยกเลิก",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "ไม่สามารถคัดลอก กรุณาคัดลอกลิงก์เอง",
    "to" : "ถึง",
    "Replace" : "แทนที่",
    "Source code" : "โค้ดต้นฉบับ",
    "Undo" : "เลิกทำ",
    "Info" : "ข้อมูล",
    "Success" : "สำเร็จ",
    "Warning" : "คำเตือน",
    "Formatting" : "การจัดรูปแบบ",
    "Edit" : "แก้ไข"
},
"nplurals=1; plural=0;");
